@@ -23,20 +23,23 @@ sub add_trigger {
 }
 
 sub append_template_file {
-    my($self, $context, $caller) = @_;
-    $caller ||= caller;
+    my($self, $context, $template_vars, $module_attribute) = @_;
+    my $caller = caller;
+
     my @template = Module::Setup::Flavor::loader($caller);
 
     for my $tmpl (@template) {
         next unless exists $tmpl->{file};
+        my $dist_path = Path::Class::File->new(@{ $module_attribute->{dist_path} }, $tmpl->{file});
+
         my $options = {
-            dist_path => $context->distribute->dist_path->file($tmpl->{file}),
+            dist_path => $dist_path,
             template  => $tmpl->{template},
-            vars      => $context->distribute->template_vars,
+            vars      => $template_vars,
             content   => undef,
         };
         $options->{chmod} = $tmpl->{chmod} if $tmpl->{chmod};
-        $context->distribute->write_template($context, $options);
+        $context->write_template($options);
     }
 }
 
@@ -62,7 +65,7 @@ module attribute setup L<Module::Setup::Plugin::VC::SVN>
 
 template parameters setup
 
-=head2 append_template_file
+=head2 append_template_file $template_vars, $module_attribute
 
 add module template file for new module L<Module::Setup::Plugin::VC::Git>
 
@@ -70,22 +73,8 @@ add module template file for new module L<Module::Setup::Plugin::VC::Git>
 
 for template process L<Module::Setup::Plugin::Template>
 
-=head2 replace_distribute_path $options
-
-for distribute path rewrite phase
-
 =head2 check_skeleton_directory
 
-  for test L<Module::Setup::Plugin::Test::Makefile>
-
-=head2 after_create_skeleton
-
-after create_skeleton
-
-=head2 finalize_create_skeleton
-
-last trigger of run method
-
 =head1 Plugin Example
 
 ~/.module-setup/flavor/myflavor/plugins/plugin.pl
